Contributors
============

jobflow was designed and developed by **Alex Ganose** |utf| |0000-0002-4486-3321|.
The project was led by **Anubhav Jain** |computron| |0000-0001-5893-9967| at Lawrence
Berkeley National Laboratory.

.. |computron| image:: https://cdnjs.cloudflare.com/ajax/libs/octicons/8.5.0/svg/mark-github.svg
   :target: https://github.com/computron
   :width: 16
   :height: 16
   :alt: GitHub profile for computron
.. |0000-0001-5893-9967| image:: _static/orcid.svg
   :target: https://orcid.org/0000-0001-5893-9967
   :width: 16
   :height: 16
   :alt: ORCID profile for 0000-0001-5893-9967
.. |utf| image:: https://cdnjs.cloudflare.com/ajax/libs/octicons/8.5.0/svg/mark-github.svg
   :target: https://github.com/utf
   :width: 16
   :height: 16
   :alt: GitHub profile for utf
.. |0000-0002-4486-3321| image:: _static/orcid.svg
   :target: https://orcid.org/0000-0002-4486-3321
   :width: 16
   :height: 16
   :alt: ORCID profile for 0000-0002-4486-3321


Additional contributions provided by:

| **David Waroquiers** |davidwaroquiers| |0000-0001-8943-9762|
| Université Catholique de Louvain

.. |davidwaroquiers| image:: https://cdnjs.cloudflare.com/ajax/libs/octicons/8.5.0/svg/mark-github.svg
   :target: https://github.com/davidwaroquiers
   :width: 16
   :height: 16
   :alt: GitHub commits from davidwaroquiers

.. |0000-0001-8943-9762| image:: _static/orcid.svg
   :target: https://orcid.org/0000-0001-8943-9762
   :width: 16
   :height: 16
   :alt: ORCID profile for 0000-0001-8943-9762
